"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.tls_subscription import TlsSubscription
from fastly.model.tls_subscription_response import TlsSubscriptionResponse
from fastly.model.tls_subscriptions_response import TlsSubscriptionsResponse


class TlsSubscriptionsApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_globalsign_email_challenge_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/subscriptions/{tls_subscription_id}/authorizations/{tls_authorization_id}/globalsign_email_challenges',
                'operation_id': 'create_globalsign_email_challenge',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_subscription_id',
                    'tls_authorization_id',
                    'request_body',
                ],
                'required': [
                    'tls_subscription_id',
                    'tls_authorization_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_subscription_id':
                        (str,),
                    'tls_authorization_id':
                        (str,),
                    'request_body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'tls_subscription_id': 'tls_subscription_id',
                    'tls_authorization_id': 'tls_authorization_id',
                },
                'location_map': {
                    'tls_subscription_id': 'path',
                    'tls_authorization_id': 'path',
                    'request_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/vnd.api+json'
                ]
            },
            api_client=api_client
        )
        self.create_tls_sub_endpoint = _Endpoint(
            settings={
                'response_type': (TlsSubscriptionResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/subscriptions',
                'operation_id': 'create_tls_sub',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'force',
                    'tls_subscription',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'force':
                        (bool,),
                    'tls_subscription':
                        (TlsSubscription,),
                },
                'attribute_map': {
                    'force': 'force',
                },
                'location_map': {
                    'force': 'query',
                    'tls_subscription': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [
                    'application/vnd.api+json'
                ]
            },
            api_client=api_client
        )
        self.delete_globalsign_email_challenge_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/subscriptions/{tls_subscription_id}/authorizations/{tls_authorization_id}/globalsign_email_challenges/{globalsign_email_challenge_id}',
                'operation_id': 'delete_globalsign_email_challenge',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_subscription_id',
                    'globalsign_email_challenge_id',
                    'tls_authorization_id',
                ],
                'required': [
                    'tls_subscription_id',
                    'globalsign_email_challenge_id',
                    'tls_authorization_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_subscription_id':
                        (str,),
                    'globalsign_email_challenge_id':
                        (str,),
                    'tls_authorization_id':
                        (str,),
                },
                'attribute_map': {
                    'tls_subscription_id': 'tls_subscription_id',
                    'globalsign_email_challenge_id': 'globalsign_email_challenge_id',
                    'tls_authorization_id': 'tls_authorization_id',
                },
                'location_map': {
                    'tls_subscription_id': 'path',
                    'globalsign_email_challenge_id': 'path',
                    'tls_authorization_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_tls_sub_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/subscriptions/{tls_subscription_id}',
                'operation_id': 'delete_tls_sub',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_subscription_id',
                ],
                'required': [
                    'tls_subscription_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_subscription_id':
                        (str,),
                },
                'attribute_map': {
                    'tls_subscription_id': 'tls_subscription_id',
                },
                'location_map': {
                    'tls_subscription_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_tls_sub_endpoint = _Endpoint(
            settings={
                'response_type': (TlsSubscriptionResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/subscriptions/{tls_subscription_id}',
                'operation_id': 'get_tls_sub',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_subscription_id',
                    'include',
                ],
                'required': [
                    'tls_subscription_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_subscription_id':
                        (str,),
                    'include':
                        (str,),
                },
                'attribute_map': {
                    'tls_subscription_id': 'tls_subscription_id',
                    'include': 'include',
                },
                'location_map': {
                    'tls_subscription_id': 'path',
                    'include': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_tls_subs_endpoint = _Endpoint(
            settings={
                'response_type': (TlsSubscriptionsResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/subscriptions',
                'operation_id': 'list_tls_subs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'filter_state',
                    'filter_tls_domains_id',
                    'filter_has_active_order',
                    'include',
                    'page_number',
                    'page_size',
                    'sort',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'page_size',
                ]
            },
            root_map={
                'validations': {
                    ('page_size',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {

                        "asc": "created_at",
                        "desc": "-created_at"
                    },
                },
                'openapi_types': {
                    'filter_state':
                        (str,),
                    'filter_tls_domains_id':
                        (str,),
                    'filter_has_active_order':
                        (bool,),
                    'include':
                        (str,),
                    'page_number':
                        (int,),
                    'page_size':
                        (int,),
                    'sort':
                        (str,),
                },
                'attribute_map': {
                    'filter_state': 'filter[state]',
                    'filter_tls_domains_id': 'filter[tls_domains.id]',
                    'filter_has_active_order': 'filter[has_active_order]',
                    'include': 'include',
                    'page_number': 'page[number]',
                    'page_size': 'page[size]',
                    'sort': 'sort',
                },
                'location_map': {
                    'filter_state': 'query',
                    'filter_tls_domains_id': 'query',
                    'filter_has_active_order': 'query',
                    'include': 'query',
                    'page_number': 'query',
                    'page_size': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.patch_tls_sub_endpoint = _Endpoint(
            settings={
                'response_type': (TlsSubscriptionResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/subscriptions/{tls_subscription_id}',
                'operation_id': 'patch_tls_sub',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_subscription_id',
                    'force',
                    'tls_subscription',
                ],
                'required': [
                    'tls_subscription_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_subscription_id':
                        (str,),
                    'force':
                        (bool,),
                    'tls_subscription':
                        (TlsSubscription,),
                },
                'attribute_map': {
                    'tls_subscription_id': 'tls_subscription_id',
                    'force': 'force',
                },
                'location_map': {
                    'tls_subscription_id': 'path',
                    'force': 'query',
                    'tls_subscription': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [
                    'application/vnd.api+json'
                ]
            },
            api_client=api_client
        )

    def create_globalsign_email_challenge(
        self,
        tls_subscription_id,
        tls_authorization_id,
        **kwargs
    ):
        """Creates a GlobalSign email challenge.  # noqa: E501

        Creates an email challenge for a domain on a GlobalSign subscription. An email challenge will generate an email that can be used to validate domain ownership. If this challenge is created, then the domain can only be validated using email for the given subscription.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_globalsign_email_challenge(tls_subscription_id, tls_authorization_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_subscription_id (str): Alphanumeric string identifying a TLS subscription.
            tls_authorization_id (str): Alphanumeric string identifying a TLS subscription.

        Keyword Args:
            request_body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_subscription_id'] = \
            tls_subscription_id
        kwargs['tls_authorization_id'] = \
            tls_authorization_id
        return self.create_globalsign_email_challenge_endpoint.call_with_http_info(**kwargs)

    def create_tls_sub(
        self,
        **kwargs
    ):
        """Create a TLS subscription  # noqa: E501

        Create a new TLS subscription. This response includes a list of possible challenges to verify domain ownership.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_tls_sub(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            force (bool): A flag that allows you to edit and delete a subscription with active domains. Valid to use on PATCH and DELETE actions. As a warning, removing an active domain from a subscription or forcing the deletion of a subscription may result in breaking TLS termination to that domain. . [optional]
            tls_subscription (TlsSubscription): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TlsSubscriptionResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.create_tls_sub_endpoint.call_with_http_info(**kwargs)

    def delete_globalsign_email_challenge(
        self,
        tls_subscription_id,
        globalsign_email_challenge_id,
        tls_authorization_id,
        **kwargs
    ):
        """Delete a GlobalSign email challenge  # noqa: E501

        Deletes a GlobalSign email challenge. After a GlobalSign email challenge is deleted, the domain can use HTTP and DNS validation methods again.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_globalsign_email_challenge(tls_subscription_id, globalsign_email_challenge_id, tls_authorization_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_subscription_id (str): Alphanumeric string identifying a TLS subscription.
            globalsign_email_challenge_id (str): Alphanumeric string identifying a GlobalSign email challenge.
            tls_authorization_id (str): Alphanumeric string identifying a TLS subscription.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_subscription_id'] = \
            tls_subscription_id
        kwargs['globalsign_email_challenge_id'] = \
            globalsign_email_challenge_id
        kwargs['tls_authorization_id'] = \
            tls_authorization_id
        return self.delete_globalsign_email_challenge_endpoint.call_with_http_info(**kwargs)

    def delete_tls_sub(
        self,
        tls_subscription_id,
        **kwargs
    ):
        """Delete a TLS subscription  # noqa: E501

        Destroy a TLS subscription. A subscription cannot be destroyed if there are domains in the TLS enabled state.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_tls_sub(tls_subscription_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_subscription_id (str): Alphanumeric string identifying a TLS subscription.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_subscription_id'] = \
            tls_subscription_id
        return self.delete_tls_sub_endpoint.call_with_http_info(**kwargs)

    def get_tls_sub(
        self,
        tls_subscription_id,
        **kwargs
    ):
        """Get a TLS subscription  # noqa: E501

        Show a TLS subscription.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_tls_sub(tls_subscription_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_subscription_id (str): Alphanumeric string identifying a TLS subscription.

        Keyword Args:
            include (str): Include related objects. Optional, comma-separated values. Permitted values: `tls_authorizations` and `tls_authorizations.globalsign_email_challenge`. . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TlsSubscriptionResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_subscription_id'] = \
            tls_subscription_id
        return self.get_tls_sub_endpoint.call_with_http_info(**kwargs)

    def list_tls_subs(
        self,
        **kwargs
    ):
        """List TLS subscriptions  # noqa: E501

        List all TLS subscriptions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_tls_subs(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            filter_state (str): Limit the returned subscriptions by state. Valid values are `pending`, `processing`, `issued`, and `renewing`. Accepts parameters: `not` (e.g., `filter[state][not]=renewing`). . [optional]
            filter_tls_domains_id (str): Limit the returned subscriptions to those that include the specific domain.. [optional]
            filter_has_active_order (bool): Limit the returned subscriptions to those that have currently active orders. Permitted values: `true`. . [optional]
            include (str): Include related objects. Optional, comma-separated values. Permitted values: `tls_authorizations` and `tls_authorizations.globalsign_email_challenge`. . [optional]
            page_number (int): Current page.. [optional]
            page_size (int): Number of records per page.. [optional] if omitted the server will use the default value of 20
            sort (str): The order in which to list the results by creation date.. [optional] if omitted the server will use the default value of "created_at"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TlsSubscriptionsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.list_tls_subs_endpoint.call_with_http_info(**kwargs)

    def patch_tls_sub(
        self,
        tls_subscription_id,
        **kwargs
    ):
        """Update a TLS subscription  # noqa: E501

        Change the TLS domains or common name associated with this subscription, or update the TLS configuration for this set of domains.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_tls_sub(tls_subscription_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_subscription_id (str): Alphanumeric string identifying a TLS subscription.

        Keyword Args:
            force (bool): A flag that allows you to edit and delete a subscription with active domains. Valid to use on PATCH and DELETE actions. As a warning, removing an active domain from a subscription or forcing the deletion of a subscription may result in breaking TLS termination to that domain. . [optional]
            tls_subscription (TlsSubscription): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TlsSubscriptionResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_subscription_id'] = \
            tls_subscription_id
        return self.patch_tls_sub_endpoint.call_with_http_info(**kwargs)




"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.tls_certificate import TlsCertificate
from fastly.model.tls_certificate_response import TlsCertificateResponse
from fastly.model.tls_certificates_response import TlsCertificatesResponse


class TlsCertificatesApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_tls_cert_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/certificates',
                'operation_id': 'create_tls_cert',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_certificate',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_certificate':
                        (TlsCertificate,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'tls_certificate': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [
                    'application/vnd.api+json'
                ]
            },
            api_client=api_client
        )
        self.delete_tls_cert_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/certificates/{tls_certificate_id}',
                'operation_id': 'delete_tls_cert',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_certificate_id',
                ],
                'required': [
                    'tls_certificate_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_certificate_id':
                        (str,),
                },
                'attribute_map': {
                    'tls_certificate_id': 'tls_certificate_id',
                },
                'location_map': {
                    'tls_certificate_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_tls_cert_endpoint = _Endpoint(
            settings={
                'response_type': (TlsCertificateResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/certificates/{tls_certificate_id}',
                'operation_id': 'get_tls_cert',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_certificate_id',
                ],
                'required': [
                    'tls_certificate_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_certificate_id':
                        (str,),
                },
                'attribute_map': {
                    'tls_certificate_id': 'tls_certificate_id',
                },
                'location_map': {
                    'tls_certificate_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_tls_certs_endpoint = _Endpoint(
            settings={
                'response_type': (TlsCertificatesResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/certificates',
                'operation_id': 'list_tls_certs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'filter_not_after',
                    'filter_tls_domains_id',
                    'include',
                    'page_number',
                    'page_size',
                    'sort',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'page_size',
                ]
            },
            root_map={
                'validations': {
                    ('page_size',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {

                        "asc": "created_at",
                        "desc": "-created_at"
                    },
                },
                'openapi_types': {
                    'filter_not_after':
                        (str,),
                    'filter_tls_domains_id':
                        (str,),
                    'include':
                        (str,),
                    'page_number':
                        (int,),
                    'page_size':
                        (int,),
                    'sort':
                        (str,),
                },
                'attribute_map': {
                    'filter_not_after': 'filter[not_after]',
                    'filter_tls_domains_id': 'filter[tls_domains.id]',
                    'include': 'include',
                    'page_number': 'page[number]',
                    'page_size': 'page[size]',
                    'sort': 'sort',
                },
                'location_map': {
                    'filter_not_after': 'query',
                    'filter_tls_domains_id': 'query',
                    'include': 'query',
                    'page_number': 'query',
                    'page_size': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_tls_cert_endpoint = _Endpoint(
            settings={
                'response_type': (TlsCertificateResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/tls/certificates/{tls_certificate_id}',
                'operation_id': 'update_tls_cert',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'tls_certificate_id',
                    'tls_certificate',
                ],
                'required': [
                    'tls_certificate_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'tls_certificate_id':
                        (str,),
                    'tls_certificate':
                        (TlsCertificate,),
                },
                'attribute_map': {
                    'tls_certificate_id': 'tls_certificate_id',
                },
                'location_map': {
                    'tls_certificate_id': 'path',
                    'tls_certificate': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [
                    'application/vnd.api+json'
                ]
            },
            api_client=api_client
        )

    def create_tls_cert(
        self,
        **kwargs
    ):
        """Create a TLS certificate  # noqa: E501

        Create a TLS certificate.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_tls_cert(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            tls_certificate (TlsCertificate): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.create_tls_cert_endpoint.call_with_http_info(**kwargs)

    def delete_tls_cert(
        self,
        tls_certificate_id,
        **kwargs
    ):
        """Delete a TLS certificate  # noqa: E501

        Destroy a TLS certificate. TLS certificates already enabled for a domain cannot be destroyed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_tls_cert(tls_certificate_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_certificate_id (str): Alphanumeric string identifying a TLS certificate.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_certificate_id'] = \
            tls_certificate_id
        return self.delete_tls_cert_endpoint.call_with_http_info(**kwargs)

    def get_tls_cert(
        self,
        tls_certificate_id,
        **kwargs
    ):
        """Get a TLS certificate  # noqa: E501

        Show a TLS certificate.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_tls_cert(tls_certificate_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_certificate_id (str): Alphanumeric string identifying a TLS certificate.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TlsCertificateResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_certificate_id'] = \
            tls_certificate_id
        return self.get_tls_cert_endpoint.call_with_http_info(**kwargs)

    def list_tls_certs(
        self,
        **kwargs
    ):
        """List TLS certificates  # noqa: E501

        List all TLS certificates.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_tls_certs(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            filter_not_after (str): Limit the returned certificates to those that expire prior to the specified date in UTC. Accepts parameters: lte (e.g., filter[not_after][lte]=2020-05-05). . [optional]
            filter_tls_domains_id (str): Limit the returned certificates to those that include the specific domain.. [optional]
            include (str): Include related objects. Optional, comma-separated values. Permitted values: `tls_activations`. . [optional]
            page_number (int): Current page.. [optional]
            page_size (int): Number of records per page.. [optional] if omitted the server will use the default value of 20
            sort (str): The order in which to list the results by creation date.. [optional] if omitted the server will use the default value of "created_at"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TlsCertificatesResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.list_tls_certs_endpoint.call_with_http_info(**kwargs)

    def update_tls_cert(
        self,
        tls_certificate_id,
        **kwargs
    ):
        """Update a TLS certificate  # noqa: E501

        Replace a TLS certificate with a newly reissued TLS certificate, or update a TLS certificate's name. If replacing a TLS certificate, the new TLS certificate must contain all SAN entries as the current TLS certificate. It must either have an exact matching list or contain a superset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_tls_cert(tls_certificate_id, async_req=True)
        >>> result = thread.get()

        Args:
            tls_certificate_id (str): Alphanumeric string identifying a TLS certificate.

        Keyword Args:
            tls_certificate (TlsCertificate): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TlsCertificateResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tls_certificate_id'] = \
            tls_certificate_id
        return self.update_tls_cert_endpoint.call_with_http_info(**kwargs)




# Do not import all APIs into this module because that uses a lot of memory and stack frames.
# If you need the ability to import all APIs from one package, import them with
# from fastly.apis import AclApi



"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.dictionary_item_response import DictionaryItemResponse
from fastly.model.inline_response200 import InlineResponse200


class DictionaryItemApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_dictionary_item_endpoint = _Endpoint(
            settings={
                'response_type': (DictionaryItemResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/dictionary/{dictionary_id}/item',
                'operation_id': 'create_dictionary_item',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'dictionary_id',
                    'item_key',
                    'item_value',
                ],
                'required': [
                    'service_id',
                    'dictionary_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'dictionary_id':
                        (str,),
                    'item_key':
                        (str,),
                    'item_value':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'dictionary_id': 'dictionary_id',
                    'item_key': 'item_key',
                    'item_value': 'item_value',
                },
                'location_map': {
                    'service_id': 'path',
                    'dictionary_id': 'path',
                    'item_key': 'form',
                    'item_value': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )
        self.delete_dictionary_item_endpoint = _Endpoint(
            settings={
                'response_type': (InlineResponse200,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/dictionary/{dictionary_id}/item/{dictionary_item_key}',
                'operation_id': 'delete_dictionary_item',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                ],
                'required': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'dictionary_id':
                        (str,),
                    'dictionary_item_key':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'dictionary_id': 'dictionary_id',
                    'dictionary_item_key': 'dictionary_item_key',
                },
                'location_map': {
                    'service_id': 'path',
                    'dictionary_id': 'path',
                    'dictionary_item_key': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_dictionary_item_endpoint = _Endpoint(
            settings={
                'response_type': (DictionaryItemResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/dictionary/{dictionary_id}/item/{dictionary_item_key}',
                'operation_id': 'get_dictionary_item',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                ],
                'required': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'dictionary_id':
                        (str,),
                    'dictionary_item_key':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'dictionary_id': 'dictionary_id',
                    'dictionary_item_key': 'dictionary_item_key',
                },
                'location_map': {
                    'service_id': 'path',
                    'dictionary_id': 'path',
                    'dictionary_item_key': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_dictionary_items_endpoint = _Endpoint(
            settings={
                'response_type': ([DictionaryItemResponse],),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/dictionary/{dictionary_id}/items',
                'operation_id': 'list_dictionary_items',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'dictionary_id',
                    'page',
                    'per_page',
                    'sort',
                    'direction',
                ],
                'required': [
                    'service_id',
                    'dictionary_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'direction',
                ],
                'validation': [
                    'per_page',
                ]
            },
            root_map={
                'validations': {
                    ('per_page',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                    ('direction',): {

                        "ASCEND": "ascend",
                        "DESCEND": "descend"
                    },
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'dictionary_id':
                        (str,),
                    'page':
                        (int,),
                    'per_page':
                        (int,),
                    'sort':
                        (str,),
                    'direction':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'dictionary_id': 'dictionary_id',
                    'page': 'page',
                    'per_page': 'per_page',
                    'sort': 'sort',
                    'direction': 'direction',
                },
                'location_map': {
                    'service_id': 'path',
                    'dictionary_id': 'path',
                    'page': 'query',
                    'per_page': 'query',
                    'sort': 'query',
                    'direction': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_dictionary_item_endpoint = _Endpoint(
            settings={
                'response_type': (DictionaryItemResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/dictionary/{dictionary_id}/item/{dictionary_item_key}',
                'operation_id': 'update_dictionary_item',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                    'item_key',
                    'item_value',
                ],
                'required': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'dictionary_id':
                        (str,),
                    'dictionary_item_key':
                        (str,),
                    'item_key':
                        (str,),
                    'item_value':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'dictionary_id': 'dictionary_id',
                    'dictionary_item_key': 'dictionary_item_key',
                    'item_key': 'item_key',
                    'item_value': 'item_value',
                },
                'location_map': {
                    'service_id': 'path',
                    'dictionary_id': 'path',
                    'dictionary_item_key': 'path',
                    'item_key': 'form',
                    'item_value': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )
        self.upsert_dictionary_item_endpoint = _Endpoint(
            settings={
                'response_type': (DictionaryItemResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/dictionary/{dictionary_id}/item/{dictionary_item_key}',
                'operation_id': 'upsert_dictionary_item',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                    'item_key',
                    'item_value',
                ],
                'required': [
                    'service_id',
                    'dictionary_id',
                    'dictionary_item_key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'dictionary_id':
                        (str,),
                    'dictionary_item_key':
                        (str,),
                    'item_key':
                        (str,),
                    'item_value':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'dictionary_id': 'dictionary_id',
                    'dictionary_item_key': 'dictionary_item_key',
                    'item_key': 'item_key',
                    'item_value': 'item_value',
                },
                'location_map': {
                    'service_id': 'path',
                    'dictionary_id': 'path',
                    'dictionary_item_key': 'path',
                    'item_key': 'form',
                    'item_value': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )

    def create_dictionary_item(
        self,
        service_id,
        dictionary_id,
        **kwargs
    ):
        """Create an entry in an edge dictionary  # noqa: E501

        Create DictionaryItem given service, dictionary ID, item key, and item value.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_dictionary_item(service_id, dictionary_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            dictionary_id (str): Alphanumeric string identifying a Dictionary.

        Keyword Args:
            item_key (str): Item key, maximum 256 characters.. [optional]
            item_value (str): Item value, maximum 8000 characters.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DictionaryItemResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['dictionary_id'] = \
            dictionary_id
        return self.create_dictionary_item_endpoint.call_with_http_info(**kwargs)

    def delete_dictionary_item(
        self,
        service_id,
        dictionary_id,
        dictionary_item_key,
        **kwargs
    ):
        """Delete an item from an edge dictionary  # noqa: E501

        Delete DictionaryItem given service, dictionary ID, and item key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_dictionary_item(service_id, dictionary_id, dictionary_item_key, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            dictionary_id (str): Alphanumeric string identifying a Dictionary.
            dictionary_item_key (str): Item key, maximum 256 characters.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            InlineResponse200
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['dictionary_id'] = \
            dictionary_id
        kwargs['dictionary_item_key'] = \
            dictionary_item_key
        return self.delete_dictionary_item_endpoint.call_with_http_info(**kwargs)

    def get_dictionary_item(
        self,
        service_id,
        dictionary_id,
        dictionary_item_key,
        **kwargs
    ):
        """Get an item from an edge dictionary  # noqa: E501

        Retrieve a single DictionaryItem given service, dictionary ID and item key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_dictionary_item(service_id, dictionary_id, dictionary_item_key, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            dictionary_id (str): Alphanumeric string identifying a Dictionary.
            dictionary_item_key (str): Item key, maximum 256 characters.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DictionaryItemResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['dictionary_id'] = \
            dictionary_id
        kwargs['dictionary_item_key'] = \
            dictionary_item_key
        return self.get_dictionary_item_endpoint.call_with_http_info(**kwargs)

    def list_dictionary_items(
        self,
        service_id,
        dictionary_id,
        **kwargs
    ):
        """List items in an edge dictionary  # noqa: E501

        List of DictionaryItems given service and dictionary ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_dictionary_items(service_id, dictionary_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            dictionary_id (str): Alphanumeric string identifying a Dictionary.

        Keyword Args:
            page (int): Current page.. [optional]
            per_page (int): Number of records per page.. [optional] if omitted the server will use the default value of 20
            sort (str): Field on which to sort.. [optional] if omitted the server will use the default value of "created"
            direction (str): Direction in which to sort results.. [optional] if omitted the server will use the default value of "ascend"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [DictionaryItemResponse]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['dictionary_id'] = \
            dictionary_id
        return self.list_dictionary_items_endpoint.call_with_http_info(**kwargs)

    def update_dictionary_item(
        self,
        service_id,
        dictionary_id,
        dictionary_item_key,
        **kwargs
    ):
        """Update an entry in an edge dictionary  # noqa: E501

        Update DictionaryItem given service, dictionary ID, item key, and item value.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_dictionary_item(service_id, dictionary_id, dictionary_item_key, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            dictionary_id (str): Alphanumeric string identifying a Dictionary.
            dictionary_item_key (str): Item key, maximum 256 characters.

        Keyword Args:
            item_key (str): Item key, maximum 256 characters.. [optional]
            item_value (str): Item value, maximum 8000 characters.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DictionaryItemResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['dictionary_id'] = \
            dictionary_id
        kwargs['dictionary_item_key'] = \
            dictionary_item_key
        return self.update_dictionary_item_endpoint.call_with_http_info(**kwargs)

    def upsert_dictionary_item(
        self,
        service_id,
        dictionary_id,
        dictionary_item_key,
        **kwargs
    ):
        """Insert or update an entry in an edge dictionary  # noqa: E501

        Upsert DictionaryItem given service, dictionary ID, item key, and item value.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upsert_dictionary_item(service_id, dictionary_id, dictionary_item_key, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            dictionary_id (str): Alphanumeric string identifying a Dictionary.
            dictionary_item_key (str): Item key, maximum 256 characters.

        Keyword Args:
            item_key (str): Item key, maximum 256 characters.. [optional]
            item_value (str): Item value, maximum 8000 characters.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DictionaryItemResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['dictionary_id'] = \
            dictionary_id
        kwargs['dictionary_item_key'] = \
            dictionary_item_key
        return self.upsert_dictionary_item_endpoint.call_with_http_info(**kwargs)




"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.customer_response import CustomerResponse
from fastly.model.inline_response200 import InlineResponse200
from fastly.model.schemas_user_response import SchemasUserResponse


class CustomerApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.delete_customer_endpoint = _Endpoint(
            settings={
                'response_type': (InlineResponse200,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/customer/{customer_id}',
                'operation_id': 'delete_customer',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_id',
                ],
                'required': [
                    'customer_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_id':
                        (str,),
                },
                'attribute_map': {
                    'customer_id': 'customer_id',
                },
                'location_map': {
                    'customer_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_customer_endpoint = _Endpoint(
            settings={
                'response_type': (CustomerResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/customer/{customer_id}',
                'operation_id': 'get_customer',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_id',
                ],
                'required': [
                    'customer_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_id':
                        (str,),
                },
                'attribute_map': {
                    'customer_id': 'customer_id',
                },
                'location_map': {
                    'customer_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_logged_in_customer_endpoint = _Endpoint(
            settings={
                'response_type': (CustomerResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/current_customer',
                'operation_id': 'get_logged_in_customer',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_users_endpoint = _Endpoint(
            settings={
                'response_type': ([SchemasUserResponse],),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/customer/{customer_id}/users',
                'operation_id': 'list_users',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_id',
                ],
                'required': [
                    'customer_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_id':
                        (str,),
                },
                'attribute_map': {
                    'customer_id': 'customer_id',
                },
                'location_map': {
                    'customer_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_customer_endpoint = _Endpoint(
            settings={
                'response_type': (CustomerResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/customer/{customer_id}',
                'operation_id': 'update_customer',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_id',
                    'billing_contact_id',
                    'billing_network_type',
                    'billing_ref',
                    'can_configure_wordpress',
                    'can_reset_passwords',
                    'can_upload_vcl',
                    'force_2fa',
                    'force_sso',
                    'has_account_panel',
                    'has_improved_events',
                    'has_improved_ssl_config',
                    'has_openstack_logging',
                    'has_pci',
                    'has_pci_passwords',
                    'ip_whitelist',
                    'legal_contact_id',
                    'name',
                    'owner_id',
                    'phone_number',
                    'postal_address',
                    'pricing_plan',
                    'pricing_plan_id',
                    'security_contact_id',
                    'technical_contact_id',
                ],
                'required': [
                    'customer_id',
                ],
                'nullable': [
                    'billing_contact_id',
                    'billing_ref',
                    'can_configure_wordpress',
                    'legal_contact_id',
                    'postal_address',
                    'security_contact_id',
                    'technical_contact_id',
                ],
                'enum': [
                    'billing_network_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('billing_network_type',): {

                        "PUBLIC": "public",
                        "PRIVATE": "private"
                    },
                },
                'openapi_types': {
                    'customer_id':
                        (str,),
                    'billing_contact_id':
                        (str, none_type,),
                    'billing_network_type':
                        (str,),
                    'billing_ref':
                        (str, none_type,),
                    'can_configure_wordpress':
                        (bool, none_type,),
                    'can_reset_passwords':
                        (bool,),
                    'can_upload_vcl':
                        (bool,),
                    'force_2fa':
                        (bool,),
                    'force_sso':
                        (bool,),
                    'has_account_panel':
                        (bool,),
                    'has_improved_events':
                        (bool,),
                    'has_improved_ssl_config':
                        (bool,),
                    'has_openstack_logging':
                        (bool,),
                    'has_pci':
                        (bool,),
                    'has_pci_passwords':
                        (bool,),
                    'ip_whitelist':
                        (str,),
                    'legal_contact_id':
                        (str, none_type,),
                    'name':
                        (str,),
                    'owner_id':
                        (str,),
                    'phone_number':
                        (str,),
                    'postal_address':
                        (str, none_type,),
                    'pricing_plan':
                        (str,),
                    'pricing_plan_id':
                        (str,),
                    'security_contact_id':
                        (str, none_type,),
                    'technical_contact_id':
                        (str, none_type,),
                },
                'attribute_map': {
                    'customer_id': 'customer_id',
                    'billing_contact_id': 'billing_contact_id',
                    'billing_network_type': 'billing_network_type',
                    'billing_ref': 'billing_ref',
                    'can_configure_wordpress': 'can_configure_wordpress',
                    'can_reset_passwords': 'can_reset_passwords',
                    'can_upload_vcl': 'can_upload_vcl',
                    'force_2fa': 'force_2fa',
                    'force_sso': 'force_sso',
                    'has_account_panel': 'has_account_panel',
                    'has_improved_events': 'has_improved_events',
                    'has_improved_ssl_config': 'has_improved_ssl_config',
                    'has_openstack_logging': 'has_openstack_logging',
                    'has_pci': 'has_pci',
                    'has_pci_passwords': 'has_pci_passwords',
                    'ip_whitelist': 'ip_whitelist',
                    'legal_contact_id': 'legal_contact_id',
                    'name': 'name',
                    'owner_id': 'owner_id',
                    'phone_number': 'phone_number',
                    'postal_address': 'postal_address',
                    'pricing_plan': 'pricing_plan',
                    'pricing_plan_id': 'pricing_plan_id',
                    'security_contact_id': 'security_contact_id',
                    'technical_contact_id': 'technical_contact_id',
                },
                'location_map': {
                    'customer_id': 'path',
                    'billing_contact_id': 'form',
                    'billing_network_type': 'form',
                    'billing_ref': 'form',
                    'can_configure_wordpress': 'form',
                    'can_reset_passwords': 'form',
                    'can_upload_vcl': 'form',
                    'force_2fa': 'form',
                    'force_sso': 'form',
                    'has_account_panel': 'form',
                    'has_improved_events': 'form',
                    'has_improved_ssl_config': 'form',
                    'has_openstack_logging': 'form',
                    'has_pci': 'form',
                    'has_pci_passwords': 'form',
                    'ip_whitelist': 'form',
                    'legal_contact_id': 'form',
                    'name': 'form',
                    'owner_id': 'form',
                    'phone_number': 'form',
                    'postal_address': 'form',
                    'pricing_plan': 'form',
                    'pricing_plan_id': 'form',
                    'security_contact_id': 'form',
                    'technical_contact_id': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )

    def delete_customer(
        self,
        customer_id,
        **kwargs
    ):
        """Delete a customer  # noqa: E501

        Delete a customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_customer(customer_id, async_req=True)
        >>> result = thread.get()

        Args:
            customer_id (str): Alphanumeric string identifying the customer.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            InlineResponse200
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['customer_id'] = \
            customer_id
        return self.delete_customer_endpoint.call_with_http_info(**kwargs)

    def get_customer(
        self,
        customer_id,
        **kwargs
    ):
        """Get a customer  # noqa: E501

        Get a specific customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_customer(customer_id, async_req=True)
        >>> result = thread.get()

        Args:
            customer_id (str): Alphanumeric string identifying the customer.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CustomerResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['customer_id'] = \
            customer_id
        return self.get_customer_endpoint.call_with_http_info(**kwargs)

    def get_logged_in_customer(
        self,
        **kwargs
    ):
        """Get the logged in customer  # noqa: E501

        Get the logged in customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_logged_in_customer(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CustomerResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_logged_in_customer_endpoint.call_with_http_info(**kwargs)

    def list_users(
        self,
        customer_id,
        **kwargs
    ):
        """List users  # noqa: E501

        List all users from a specified customer id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_users(customer_id, async_req=True)
        >>> result = thread.get()

        Args:
            customer_id (str): Alphanumeric string identifying the customer.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [SchemasUserResponse]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['customer_id'] = \
            customer_id
        return self.list_users_endpoint.call_with_http_info(**kwargs)

    def update_customer(
        self,
        customer_id,
        **kwargs
    ):
        """Update a customer  # noqa: E501

        Update a customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_customer(customer_id, async_req=True)
        >>> result = thread.get()

        Args:
            customer_id (str): Alphanumeric string identifying the customer.

        Keyword Args:
            billing_contact_id (str, none_type): The alphanumeric string representing the primary billing contact.. [optional]
            billing_network_type (str): Customer's current network revenue type.. [optional]
            billing_ref (str, none_type): Used for adding purchased orders to customer's account.. [optional]
            can_configure_wordpress (bool, none_type): Whether this customer can view or edit wordpress.. [optional]
            can_reset_passwords (bool): Whether this customer can reset passwords.. [optional]
            can_upload_vcl (bool): Whether this customer can upload VCL.. [optional]
            force_2fa (bool): Specifies whether 2FA is forced or not forced on the customer account. Logs out non-2FA users once 2FA is force enabled.. [optional]
            force_sso (bool): Specifies whether SSO is forced or not forced on the customer account.. [optional]
            has_account_panel (bool): Specifies whether the account has access or does not have access to the account panel.. [optional]
            has_improved_events (bool): Specifies whether the account has access or does not have access to the improved events.. [optional]
            has_improved_ssl_config (bool): Whether this customer can view or edit the SSL config.. [optional]
            has_openstack_logging (bool): Specifies whether the account has enabled or not enabled openstack logging.. [optional]
            has_pci (bool): Specifies whether the account can edit PCI for a service.. [optional]
            has_pci_passwords (bool): Specifies whether PCI passwords are required for the account.. [optional]
            ip_whitelist (str): The range of IP addresses authorized to access the customer account.. [optional]
            legal_contact_id (str, none_type): The alphanumeric string identifying the account's legal contact.. [optional]
            name (str): The name of the customer, generally the company name.. [optional]
            owner_id (str): The alphanumeric string identifying the account owner.. [optional]
            phone_number (str): The phone number associated with the account.. [optional]
            postal_address (str, none_type): The postal address associated with the account.. [optional]
            pricing_plan (str): The pricing plan this customer is under.. [optional]
            pricing_plan_id (str): The alphanumeric string identifying the pricing plan.. [optional]
            security_contact_id (str, none_type): The alphanumeric string identifying the account's security contact.. [optional]
            technical_contact_id (str, none_type): The alphanumeric string identifying the account's technical contact.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CustomerResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['customer_id'] = \
            customer_id
        return self.update_customer_endpoint.call_with_http_info(**kwargs)




"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.backend_response import BackendResponse
from fastly.model.inline_response200 import InlineResponse200


class BackendApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_backend_endpoint = _Endpoint(
            settings={
                'response_type': (BackendResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/version/{version_id}/backend',
                'operation_id': 'create_backend',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'version_id',
                    'address',
                    'auto_loadbalance',
                    'between_bytes_timeout',
                    'client_cert',
                    'comment',
                    'connect_timeout',
                    'first_byte_timeout',
                    'healthcheck',
                    'hostname',
                    'ipv4',
                    'ipv6',
                    'keepalive_time',
                    'max_conn',
                    'max_tls_version',
                    'min_tls_version',
                    'name',
                    'override_host',
                    'port',
                    'request_condition',
                    'shield',
                    'ssl_ca_cert',
                    'ssl_cert_hostname',
                    'ssl_check_cert',
                    'ssl_ciphers',
                    'ssl_client_cert',
                    'ssl_client_key',
                    'ssl_hostname',
                    'ssl_sni_hostname',
                    'use_ssl',
                    'weight',
                ],
                'required': [
                    'service_id',
                    'version_id',
                ],
                'nullable': [
                    'client_cert',
                    'comment',
                    'healthcheck',
                    'hostname',
                    'ipv4',
                    'ipv6',
                    'keepalive_time',
                    'max_tls_version',
                    'min_tls_version',
                    'override_host',
                    'shield',
                    'ssl_ca_cert',
                    'ssl_cert_hostname',
                    'ssl_ciphers',
                    'ssl_client_cert',
                    'ssl_client_key',
                    'ssl_hostname',
                    'ssl_sni_hostname',
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'version_id':
                        (int,),
                    'address':
                        (str,),
                    'auto_loadbalance':
                        (bool,),
                    'between_bytes_timeout':
                        (int,),
                    'client_cert':
                        (str, none_type,),
                    'comment':
                        (str, none_type,),
                    'connect_timeout':
                        (int,),
                    'first_byte_timeout':
                        (int,),
                    'healthcheck':
                        (str, none_type,),
                    'hostname':
                        (str, none_type,),
                    'ipv4':
                        (str, none_type,),
                    'ipv6':
                        (str, none_type,),
                    'keepalive_time':
                        (int, none_type,),
                    'max_conn':
                        (int,),
                    'max_tls_version':
                        (str, none_type,),
                    'min_tls_version':
                        (str, none_type,),
                    'name':
                        (str,),
                    'override_host':
                        (str, none_type,),
                    'port':
                        (int,),
                    'request_condition':
                        (str,),
                    'shield':
                        (str, none_type,),
                    'ssl_ca_cert':
                        (str, none_type,),
                    'ssl_cert_hostname':
                        (str, none_type,),
                    'ssl_check_cert':
                        (bool,),
                    'ssl_ciphers':
                        (str, none_type,),
                    'ssl_client_cert':
                        (str, none_type,),
                    'ssl_client_key':
                        (str, none_type,),
                    'ssl_hostname':
                        (str, none_type,),
                    'ssl_sni_hostname':
                        (str, none_type,),
                    'use_ssl':
                        (bool,),
                    'weight':
                        (int,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'version_id': 'version_id',
                    'address': 'address',
                    'auto_loadbalance': 'auto_loadbalance',
                    'between_bytes_timeout': 'between_bytes_timeout',
                    'client_cert': 'client_cert',
                    'comment': 'comment',
                    'connect_timeout': 'connect_timeout',
                    'first_byte_timeout': 'first_byte_timeout',
                    'healthcheck': 'healthcheck',
                    'hostname': 'hostname',
                    'ipv4': 'ipv4',
                    'ipv6': 'ipv6',
                    'keepalive_time': 'keepalive_time',
                    'max_conn': 'max_conn',
                    'max_tls_version': 'max_tls_version',
                    'min_tls_version': 'min_tls_version',
                    'name': 'name',
                    'override_host': 'override_host',
                    'port': 'port',
                    'request_condition': 'request_condition',
                    'shield': 'shield',
                    'ssl_ca_cert': 'ssl_ca_cert',
                    'ssl_cert_hostname': 'ssl_cert_hostname',
                    'ssl_check_cert': 'ssl_check_cert',
                    'ssl_ciphers': 'ssl_ciphers',
                    'ssl_client_cert': 'ssl_client_cert',
                    'ssl_client_key': 'ssl_client_key',
                    'ssl_hostname': 'ssl_hostname',
                    'ssl_sni_hostname': 'ssl_sni_hostname',
                    'use_ssl': 'use_ssl',
                    'weight': 'weight',
                },
                'location_map': {
                    'service_id': 'path',
                    'version_id': 'path',
                    'address': 'form',
                    'auto_loadbalance': 'form',
                    'between_bytes_timeout': 'form',
                    'client_cert': 'form',
                    'comment': 'form',
                    'connect_timeout': 'form',
                    'first_byte_timeout': 'form',
                    'healthcheck': 'form',
                    'hostname': 'form',
                    'ipv4': 'form',
                    'ipv6': 'form',
                    'keepalive_time': 'form',
                    'max_conn': 'form',
                    'max_tls_version': 'form',
                    'min_tls_version': 'form',
                    'name': 'form',
                    'override_host': 'form',
                    'port': 'form',
                    'request_condition': 'form',
                    'shield': 'form',
                    'ssl_ca_cert': 'form',
                    'ssl_cert_hostname': 'form',
                    'ssl_check_cert': 'form',
                    'ssl_ciphers': 'form',
                    'ssl_client_cert': 'form',
                    'ssl_client_key': 'form',
                    'ssl_hostname': 'form',
                    'ssl_sni_hostname': 'form',
                    'use_ssl': 'form',
                    'weight': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )
        self.delete_backend_endpoint = _Endpoint(
            settings={
                'response_type': (InlineResponse200,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/version/{version_id}/backend/{backend_name}',
                'operation_id': 'delete_backend',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'version_id',
                    'backend_name',
                ],
                'required': [
                    'service_id',
                    'version_id',
                    'backend_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'version_id':
                        (int,),
                    'backend_name':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'version_id': 'version_id',
                    'backend_name': 'backend_name',
                },
                'location_map': {
                    'service_id': 'path',
                    'version_id': 'path',
                    'backend_name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_backend_endpoint = _Endpoint(
            settings={
                'response_type': (BackendResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/version/{version_id}/backend/{backend_name}',
                'operation_id': 'get_backend',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'version_id',
                    'backend_name',
                ],
                'required': [
                    'service_id',
                    'version_id',
                    'backend_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'version_id':
                        (int,),
                    'backend_name':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'version_id': 'version_id',
                    'backend_name': 'backend_name',
                },
                'location_map': {
                    'service_id': 'path',
                    'version_id': 'path',
                    'backend_name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_backends_endpoint = _Endpoint(
            settings={
                'response_type': ([BackendResponse],),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/version/{version_id}/backend',
                'operation_id': 'list_backends',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'version_id',
                ],
                'required': [
                    'service_id',
                    'version_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'version_id':
                        (int,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'version_id': 'version_id',
                },
                'location_map': {
                    'service_id': 'path',
                    'version_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_backend_endpoint = _Endpoint(
            settings={
                'response_type': (BackendResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/version/{version_id}/backend/{backend_name}',
                'operation_id': 'update_backend',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'service_id',
                    'version_id',
                    'backend_name',
                    'address',
                    'auto_loadbalance',
                    'between_bytes_timeout',
                    'client_cert',
                    'comment',
                    'connect_timeout',
                    'first_byte_timeout',
                    'healthcheck',
                    'hostname',
                    'ipv4',
                    'ipv6',
                    'keepalive_time',
                    'max_conn',
                    'max_tls_version',
                    'min_tls_version',
                    'name',
                    'override_host',
                    'port',
                    'request_condition',
                    'shield',
                    'ssl_ca_cert',
                    'ssl_cert_hostname',
                    'ssl_check_cert',
                    'ssl_ciphers',
                    'ssl_client_cert',
                    'ssl_client_key',
                    'ssl_hostname',
                    'ssl_sni_hostname',
                    'use_ssl',
                    'weight',
                ],
                'required': [
                    'service_id',
                    'version_id',
                    'backend_name',
                ],
                'nullable': [
                    'client_cert',
                    'comment',
                    'healthcheck',
                    'hostname',
                    'ipv4',
                    'ipv6',
                    'keepalive_time',
                    'max_tls_version',
                    'min_tls_version',
                    'override_host',
                    'shield',
                    'ssl_ca_cert',
                    'ssl_cert_hostname',
                    'ssl_ciphers',
                    'ssl_client_cert',
                    'ssl_client_key',
                    'ssl_hostname',
                    'ssl_sni_hostname',
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'version_id':
                        (int,),
                    'backend_name':
                        (str,),
                    'address':
                        (str,),
                    'auto_loadbalance':
                        (bool,),
                    'between_bytes_timeout':
                        (int,),
                    'client_cert':
                        (str, none_type,),
                    'comment':
                        (str, none_type,),
                    'connect_timeout':
                        (int,),
                    'first_byte_timeout':
                        (int,),
                    'healthcheck':
                        (str, none_type,),
                    'hostname':
                        (str, none_type,),
                    'ipv4':
                        (str, none_type,),
                    'ipv6':
                        (str, none_type,),
                    'keepalive_time':
                        (int, none_type,),
                    'max_conn':
                        (int,),
                    'max_tls_version':
                        (str, none_type,),
                    'min_tls_version':
                        (str, none_type,),
                    'name':
                        (str,),
                    'override_host':
                        (str, none_type,),
                    'port':
                        (int,),
                    'request_condition':
                        (str,),
                    'shield':
                        (str, none_type,),
                    'ssl_ca_cert':
                        (str, none_type,),
                    'ssl_cert_hostname':
                        (str, none_type,),
                    'ssl_check_cert':
                        (bool,),
                    'ssl_ciphers':
                        (str, none_type,),
                    'ssl_client_cert':
                        (str, none_type,),
                    'ssl_client_key':
                        (str, none_type,),
                    'ssl_hostname':
                        (str, none_type,),
                    'ssl_sni_hostname':
                        (str, none_type,),
                    'use_ssl':
                        (bool,),
                    'weight':
                        (int,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'version_id': 'version_id',
                    'backend_name': 'backend_name',
                    'address': 'address',
                    'auto_loadbalance': 'auto_loadbalance',
                    'between_bytes_timeout': 'between_bytes_timeout',
                    'client_cert': 'client_cert',
                    'comment': 'comment',
                    'connect_timeout': 'connect_timeout',
                    'first_byte_timeout': 'first_byte_timeout',
                    'healthcheck': 'healthcheck',
                    'hostname': 'hostname',
                    'ipv4': 'ipv4',
                    'ipv6': 'ipv6',
                    'keepalive_time': 'keepalive_time',
                    'max_conn': 'max_conn',
                    'max_tls_version': 'max_tls_version',
                    'min_tls_version': 'min_tls_version',
                    'name': 'name',
                    'override_host': 'override_host',
                    'port': 'port',
                    'request_condition': 'request_condition',
                    'shield': 'shield',
                    'ssl_ca_cert': 'ssl_ca_cert',
                    'ssl_cert_hostname': 'ssl_cert_hostname',
                    'ssl_check_cert': 'ssl_check_cert',
                    'ssl_ciphers': 'ssl_ciphers',
                    'ssl_client_cert': 'ssl_client_cert',
                    'ssl_client_key': 'ssl_client_key',
                    'ssl_hostname': 'ssl_hostname',
                    'ssl_sni_hostname': 'ssl_sni_hostname',
                    'use_ssl': 'use_ssl',
                    'weight': 'weight',
                },
                'location_map': {
                    'service_id': 'path',
                    'version_id': 'path',
                    'backend_name': 'path',
                    'address': 'form',
                    'auto_loadbalance': 'form',
                    'between_bytes_timeout': 'form',
                    'client_cert': 'form',
                    'comment': 'form',
                    'connect_timeout': 'form',
                    'first_byte_timeout': 'form',
                    'healthcheck': 'form',
                    'hostname': 'form',
                    'ipv4': 'form',
                    'ipv6': 'form',
                    'keepalive_time': 'form',
                    'max_conn': 'form',
                    'max_tls_version': 'form',
                    'min_tls_version': 'form',
                    'name': 'form',
                    'override_host': 'form',
                    'port': 'form',
                    'request_condition': 'form',
                    'shield': 'form',
                    'ssl_ca_cert': 'form',
                    'ssl_cert_hostname': 'form',
                    'ssl_check_cert': 'form',
                    'ssl_ciphers': 'form',
                    'ssl_client_cert': 'form',
                    'ssl_client_key': 'form',
                    'ssl_hostname': 'form',
                    'ssl_sni_hostname': 'form',
                    'use_ssl': 'form',
                    'weight': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )

    def create_backend(
        self,
        service_id,
        version_id,
        **kwargs
    ):
        """Create a backend  # noqa: E501

        Create a backend for a particular service and version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_backend(service_id, version_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            version_id (int): Integer identifying a service version.

        Keyword Args:
            address (str): A hostname, IPv4, or IPv6 address for the backend. This is the preferred way to specify the location of your backend.. [optional]
            auto_loadbalance (bool): Whether or not this backend should be automatically load balanced. If true, all backends with this setting that don't have a `request_condition` will be selected based on their `weight`.. [optional]
            between_bytes_timeout (int): Maximum duration in milliseconds that Fastly will wait while receiving no data on a download from a backend. If exceeded, the response received so far will be considered complete and the fetch will end. May be set at runtime using `bereq.between_bytes_timeout`.. [optional]
            client_cert (str, none_type): Unused.. [optional]
            comment (str, none_type): A freeform descriptive note.. [optional]
            connect_timeout (int): Maximum duration in milliseconds to wait for a connection to this backend to be established. If exceeded, the connection is aborted and a synthethic `503` response will be presented instead. May be set at runtime using `bereq.connect_timeout`.. [optional]
            first_byte_timeout (int): Maximum duration in milliseconds to wait for the server response to begin after a TCP connection is established and the request has been sent. If exceeded, the connection is aborted and a synthethic `503` response will be presented instead. May be set at runtime using `bereq.first_byte_timeout`.. [optional]
            healthcheck (str, none_type): The name of the healthcheck to use with this backend.. [optional]
            hostname (str, none_type): The hostname of the backend. May be used as an alternative to `address` to set the backend location.. [optional]
            ipv4 (str, none_type): IPv4 address of the backend. May be used as an alternative to `address` to set the backend location.. [optional]
            ipv6 (str, none_type): IPv6 address of the backend. May be used as an alternative to `address` to set the backend location.. [optional]
            keepalive_time (int, none_type): How long to keep a persistent connection to the backend between requests.. [optional]
            max_conn (int): Maximum number of concurrent connections this backend will accept.. [optional]
            max_tls_version (str, none_type): Maximum allowed TLS version on SSL connections to this backend. If your backend server is not able to negotiate a connection meeting this constraint, a synthetic `503` error response will be generated.. [optional]
            min_tls_version (str, none_type): Minimum allowed TLS version on SSL connections to this backend. If your backend server is not able to negotiate a connection meeting this constraint, a synthetic `503` error response will be generated.. [optional]
            name (str): The name of the backend.. [optional]
            override_host (str, none_type): If set, will replace the client-supplied HTTP `Host` header on connections to this backend. Applied after VCL has been processed, so this setting will take precedence over changing `bereq.http.Host` in VCL.. [optional]
            port (int): Port on which the backend server is listening for connections from Fastly. Setting `port` to 80 or 443 will also set `use_ssl` automatically (to false and true respectively), unless explicitly overridden by setting `use_ssl` in the same request.. [optional]
            request_condition (str): Name of a Condition, which if satisfied, will select this backend during a request. If set, will override any `auto_loadbalance` setting. By default, the first backend added to a service is selected for all requests.. [optional]
            shield (str, none_type): Identifier of the POP to use as a [shield](https://docs.fastly.com/en/guides/shielding).. [optional]
            ssl_ca_cert (str, none_type): CA certificate attached to origin.. [optional]
            ssl_cert_hostname (str, none_type): Overrides `ssl_hostname`, but only for cert verification. Does not affect SNI at all.. [optional]
            ssl_check_cert (bool): Be strict on checking SSL certs.. [optional] if omitted the server will use the default value of True
            ssl_ciphers (str, none_type): List of [OpenSSL ciphers](https://www.openssl.org/docs/manmaster/man1/ciphers.html) to support for connections to this origin. If your backend server is not able to negotiate a connection meeting this constraint, a synthetic `503` error response will be generated.. [optional]
            ssl_client_cert (str, none_type): Client certificate attached to origin.. [optional]
            ssl_client_key (str, none_type): Client key attached to origin.. [optional]
            ssl_hostname (str, none_type): Use `ssl_cert_hostname` and `ssl_sni_hostname` to configure certificate validation.. [optional]
            ssl_sni_hostname (str, none_type): Overrides `ssl_hostname`, but only for SNI in the handshake. Does not affect cert validation at all.. [optional]
            use_ssl (bool): Whether or not to require TLS for connections to this backend.. [optional]
            weight (int): Weight used to load balance this backend against others. May be any positive integer. If `auto_loadbalance` is true, the chance of this backend being selected is equal to its own weight over the sum of all weights for backends that have `auto_loadbalance` set to true.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            BackendResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['version_id'] = \
            version_id
        return self.create_backend_endpoint.call_with_http_info(**kwargs)

    def delete_backend(
        self,
        service_id,
        version_id,
        backend_name,
        **kwargs
    ):
        """Delete a backend  # noqa: E501

        Delete the backend for a particular service and version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_backend(service_id, version_id, backend_name, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            version_id (int): Integer identifying a service version.
            backend_name (str): The name of the backend.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            InlineResponse200
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['version_id'] = \
            version_id
        kwargs['backend_name'] = \
            backend_name
        return self.delete_backend_endpoint.call_with_http_info(**kwargs)

    def get_backend(
        self,
        service_id,
        version_id,
        backend_name,
        **kwargs
    ):
        """Describe a backend  # noqa: E501

        Get the backend for a particular service and version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_backend(service_id, version_id, backend_name, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            version_id (int): Integer identifying a service version.
            backend_name (str): The name of the backend.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            BackendResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['version_id'] = \
            version_id
        kwargs['backend_name'] = \
            backend_name
        return self.get_backend_endpoint.call_with_http_info(**kwargs)

    def list_backends(
        self,
        service_id,
        version_id,
        **kwargs
    ):
        """List backends  # noqa: E501

        List all backends for a particular service and version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_backends(service_id, version_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            version_id (int): Integer identifying a service version.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [BackendResponse]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['version_id'] = \
            version_id
        return self.list_backends_endpoint.call_with_http_info(**kwargs)

    def update_backend(
        self,
        service_id,
        version_id,
        backend_name,
        **kwargs
    ):
        """Update a backend  # noqa: E501

        Update the backend for a particular service and version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_backend(service_id, version_id, backend_name, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            version_id (int): Integer identifying a service version.
            backend_name (str): The name of the backend.

        Keyword Args:
            address (str): A hostname, IPv4, or IPv6 address for the backend. This is the preferred way to specify the location of your backend.. [optional]
            auto_loadbalance (bool): Whether or not this backend should be automatically load balanced. If true, all backends with this setting that don't have a `request_condition` will be selected based on their `weight`.. [optional]
            between_bytes_timeout (int): Maximum duration in milliseconds that Fastly will wait while receiving no data on a download from a backend. If exceeded, the response received so far will be considered complete and the fetch will end. May be set at runtime using `bereq.between_bytes_timeout`.. [optional]
            client_cert (str, none_type): Unused.. [optional]
            comment (str, none_type): A freeform descriptive note.. [optional]
            connect_timeout (int): Maximum duration in milliseconds to wait for a connection to this backend to be established. If exceeded, the connection is aborted and a synthethic `503` response will be presented instead. May be set at runtime using `bereq.connect_timeout`.. [optional]
            first_byte_timeout (int): Maximum duration in milliseconds to wait for the server response to begin after a TCP connection is established and the request has been sent. If exceeded, the connection is aborted and a synthethic `503` response will be presented instead. May be set at runtime using `bereq.first_byte_timeout`.. [optional]
            healthcheck (str, none_type): The name of the healthcheck to use with this backend.. [optional]
            hostname (str, none_type): The hostname of the backend. May be used as an alternative to `address` to set the backend location.. [optional]
            ipv4 (str, none_type): IPv4 address of the backend. May be used as an alternative to `address` to set the backend location.. [optional]
            ipv6 (str, none_type): IPv6 address of the backend. May be used as an alternative to `address` to set the backend location.. [optional]
            keepalive_time (int, none_type): How long to keep a persistent connection to the backend between requests.. [optional]
            max_conn (int): Maximum number of concurrent connections this backend will accept.. [optional]
            max_tls_version (str, none_type): Maximum allowed TLS version on SSL connections to this backend. If your backend server is not able to negotiate a connection meeting this constraint, a synthetic `503` error response will be generated.. [optional]
            min_tls_version (str, none_type): Minimum allowed TLS version on SSL connections to this backend. If your backend server is not able to negotiate a connection meeting this constraint, a synthetic `503` error response will be generated.. [optional]
            name (str): The name of the backend.. [optional]
            override_host (str, none_type): If set, will replace the client-supplied HTTP `Host` header on connections to this backend. Applied after VCL has been processed, so this setting will take precedence over changing `bereq.http.Host` in VCL.. [optional]
            port (int): Port on which the backend server is listening for connections from Fastly. Setting `port` to 80 or 443 will also set `use_ssl` automatically (to false and true respectively), unless explicitly overridden by setting `use_ssl` in the same request.. [optional]
            request_condition (str): Name of a Condition, which if satisfied, will select this backend during a request. If set, will override any `auto_loadbalance` setting. By default, the first backend added to a service is selected for all requests.. [optional]
            shield (str, none_type): Identifier of the POP to use as a [shield](https://docs.fastly.com/en/guides/shielding).. [optional]
            ssl_ca_cert (str, none_type): CA certificate attached to origin.. [optional]
            ssl_cert_hostname (str, none_type): Overrides `ssl_hostname`, but only for cert verification. Does not affect SNI at all.. [optional]
            ssl_check_cert (bool): Be strict on checking SSL certs.. [optional] if omitted the server will use the default value of True
            ssl_ciphers (str, none_type): List of [OpenSSL ciphers](https://www.openssl.org/docs/manmaster/man1/ciphers.html) to support for connections to this origin. If your backend server is not able to negotiate a connection meeting this constraint, a synthetic `503` error response will be generated.. [optional]
            ssl_client_cert (str, none_type): Client certificate attached to origin.. [optional]
            ssl_client_key (str, none_type): Client key attached to origin.. [optional]
            ssl_hostname (str, none_type): Use `ssl_cert_hostname` and `ssl_sni_hostname` to configure certificate validation.. [optional]
            ssl_sni_hostname (str, none_type): Overrides `ssl_hostname`, but only for SNI in the handshake. Does not affect cert validation at all.. [optional]
            use_ssl (bool): Whether or not to require TLS for connections to this backend.. [optional]
            weight (int): Weight used to load balance this backend against others. May be any positive integer. If `auto_loadbalance` is true, the chance of this backend being selected is equal to its own weight over the sum of all weights for backends that have `auto_loadbalance` set to true.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            BackendResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['version_id'] = \
            version_id
        kwargs['backend_name'] = \
            backend_name
        return self.update_backend_endpoint.call_with_http_info(**kwargs)

